@@ -6,6 +6,11 @@ constantDensitySampling <- function(x, polygon.id='pID', parallel=FALSE, cores=N
     stop('please install the `terra` package', call. = FALSE)
   }
   
+  # attempt conversion to terra object
+  if (!inherits(x, 'SpatVector')) {
+    x <- terra::vect(x)
+  }
+  
   # sanity check: this must be a projected CRS
   if (terra::is.lonlat(x)) {
     stop('input polygons must be in a projected coordinate system with units of meters', call. = FALSE)
@@ -118,14 +123,23 @@ sample.by.poly <- function(p,
     stop('please install the `terra` package', call. = FALSE)
   }
   
+  # attempt conversion to terra object
+  if (!inherits(p, 'SpatVector')) {
+    p <- terra::vect(p)
+  }
+  
   # convert _projected_ units to acres
   ac.i <- terra::expanse(p) * 2.47e-4
   
   # determine number of points based on requested density
   n.samples <- round(ac.i * n.pts.per.ac)
   
-  # polygon must be at least large enough to support requested number of samples
-  if (n.samples >= min.samples) {
+  # if polygon is too small for given density, request the minimum number of samples
+  if (n.samples < min.samples) {
+    n.samples <- min.samples
+  }
+  
+  if (n.samples > 0) {
     # trap errors caused by bad geometry
     s.i <- try(terra::spatSample(p, size = n.samples, method = sampling.type), silent = TRUE)
     
@@ -143,5 +157,5 @@ sample.by.poly <- function(p,
       terra::crs(s.i) <- p4s
     
     return(s.i)
-  } else return(NULL)
+  } else return(p[0,])
 }
